DirectoryEntry

Struct DirectoryEntry 

pub struct DirectoryEntry {
    pub metadata: Metadata,
    /* private fields */
}
A directory entry: either a file or a directory.

Fields

metadata: Metadata

Metadata for this entry (name, path, cluster, timestamps, etc.).

Implementations

Source

impl DirectoryEntry

pub fn new_file(metadata: Metadata, vfat_filesystem: VfatFS) -> Self

Create a new file-typed directory entry.

pub fn new_directory(metadata: Metadata, vfat_filesystem: VfatFS) -> Self

Create a new directory-typed directory entry.

Source

impl DirectoryEntry

pub fn into_directory(self) -> Option<Directory>

Convert into a Directory, returning None if this is a file.

pub fn into_directory_unchecked(self) -> Directory

Convert into a Directory without checking the entry kind.

pub fn into_directory_or_not_found(self) -> Result<Directory>

Convert into a Directory, returning [VfatRsError::EntryNotFound] if this is a file.

pub fn into_file(self) -> Option<File>

Convert into a [File], returning None if this is a directory.

pub fn into_file_unchecked(self) -> File

Convert into a [File], panicking if this is a directory.